source $PREFIX/bin/activate $PREFIX
cd h2o-py
# patch current version into
# echo $PKG_VERSION > h2o/version.txt
H2O_BUILD_PY=true ../gradlew -PdoPython -Ph2o.web.allow.root build
# python setup.py install --single-version-externally-managed --record=record.txt
